@@ -31,6 +31,7 @@
 #include "tb_timer_stopped.xpm"
 
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 #include <glibtop/close.h>
 
@@ -211,7 +212,7 @@ main (int argc, char *argv[])
 
 	gnome_init_with_popt_table ("gtop", VERSION, argc, argv,
 				    gtop_options, 0, &ctx);
-	
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gtop.png");
 	args = poptGetArgs (ctx);
 
 	poptFreeContext (ctx);
